'use strict';

var React = require('react');
var reactRouterDom = require('react-router-dom');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var React__default = /*#__PURE__*/_interopDefaultLegacy(React);

var DEFAULT_SCROLL_BEHAVIOR = "smooth";
var DEFAULT_SCROLL_POSITION = "center";

var DEFAULT_SCROLL_FUNC = function (ref, behavior, position) { var _a; return (_a = ref.current) === null || _a === void 0 ? void 0 : _a.scrollIntoView({
    behavior: behavior,
    block: position,
    inline: position,
}); };

/**
 * Scrolls to child element when the specified hash is present in the url
 *
 * Note: **ONLY** 1 child element allowed
 */
var HashScroll = function (_a) {
    var hash = _a.hash, children = _a.children, _b = _a.behavior, behavior = _b === void 0 ? DEFAULT_SCROLL_BEHAVIOR : _b, _c = _a.position, position = _c === void 0 ? DEFAULT_SCROLL_POSITION : _c, requiredPathname = _a.requiredPathname, scrollFunc = _a.scrollFunc;
    var _d = reactRouterDom.useLocation(), urlHash = _d.hash, pathname = _d.pathname;
    var childRef = React.useRef(null);
    if (hash.charAt(0) !== "#") {
        hash = "#" + hash;
    }
    if (typeof requiredPathname === "string") {
        requiredPathname = [requiredPathname];
    }
    React.useEffect(function () {
        if (urlHash === hash &&
            (requiredPathname === undefined || requiredPathname.includes(pathname))) {
            if (childRef.current) {
                if (scrollFunc)
                    scrollFunc(childRef, behavior, position);
                else
                    DEFAULT_SCROLL_FUNC(childRef, behavior, position);
            }
        }
    }, [urlHash, childRef, hash]);
    return React.cloneElement(children, {
        ref: childRef,
    });
};

// React Imports
var createHashFunc = function (ref, options, defaultOptions, pathname) {
    var _a, _b, _c, _d, _e;
    var behavior = defaultOptions.behavior, position = defaultOptions.position, requiredPathname = defaultOptions.requiredPathname, scrollFunc = defaultOptions.scrollFunc;
    var req = (_a = options.requiredPathname) !== null && _a !== void 0 ? _a : requiredPathname;
    if (typeof req === "string")
        req = [req];
    var b = (_c = (_b = options.behavior) !== null && _b !== void 0 ? _b : behavior) !== null && _c !== void 0 ? _c : DEFAULT_SCROLL_BEHAVIOR;
    var p = (_e = (_d = options.position) !== null && _d !== void 0 ? _d : position) !== null && _e !== void 0 ? _e : DEFAULT_SCROLL_POSITION;
    return function () {
        if ((req === undefined || req.includes(pathname)) && ref.current) {
            if (options.scrollFunc)
                options.scrollFunc(ref, b, p);
            else if (scrollFunc)
                scrollFunc(ref, b, p);
            else
                DEFAULT_SCROLL_FUNC(ref, b, p);
        }
    };
};
/**
 * Component that pairs hashes with refs and scrolls to a corresponding ref when one of the hashes is present in the url
 */
var MultiHash = function (_a) {
    var hashes = _a.hashes, children = _a.children, behavior = _a.behavior, position = _a.position, requiredPathname = _a.requiredPathname, scrollFunc = _a.scrollFunc;
    var _b = reactRouterDom.useLocation(), urlHash = _b.hash, pathname = _b.pathname;
    var defaultOptions = React.useMemo(function () { return ({ behavior: behavior, position: position, requiredPathname: requiredPathname, scrollFunc: scrollFunc }); }, [behavior, position, requiredPathname, scrollFunc]);
    var hashFuncs = React.useMemo(function () { return ({}); }, [
        hashes,
        defaultOptions,
        pathname,
    ]);
    React.useMemo(function () {
        for (var hash in hashes) {
            var value = hashes[hash];
            if (hash.charAt(0) !== "#") {
                hash = "#" + hash;
            }
            if (Array.isArray(value))
                hashFuncs[hash] = createHashFunc(value[0], value[1], defaultOptions, pathname);
            else
                hashFuncs[hash] = createHashFunc(value, {}, defaultOptions, pathname);
        }
    }, [hashes, defaultOptions, pathname]);
    React.useEffect(function () {
        var scroll = hashFuncs[urlHash];
        if (typeof scroll === "function") {
            scroll();
        }
    }, [urlHash, hashFuncs]);
    return React__default['default'].createElement(React__default['default'].Fragment, null, children);
};

exports.DEFAULT_SCROLL_BEHAVIOR = DEFAULT_SCROLL_BEHAVIOR;
exports.DEFAULT_SCROLL_FUNC = DEFAULT_SCROLL_FUNC;
exports.DEFAULT_SCROLL_POSITION = DEFAULT_SCROLL_POSITION;
exports.HashScroll = HashScroll;
exports.MultiHash = MultiHash;
//# sourceMappingURL=react-hash-scroll.js.map
